@@ -1,20 +1,7 @@
 /*
-  Copyright (C) 2006-2007 KovoKs <info@kovoks.nl>
+  SPDX-FileCopyrightText: 2006-2007 KovoKs <info@kovoks.nl>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // Uncomment the next line for full comm debug
@@ -25,7 +12,6 @@
 
 // Qt
 #include <QByteArray>
-#include <QSslSocket>
 #include <QNetworkProxy>
 // KDE
 #include "mailtransport_debug.h"
@@ -34,36 +20,31 @@ using namespace MailTransport;
 
 namespace MailTransport
 {
-
 class SocketPrivate
 {
 public:
     SocketPrivate(Socket *s);
-    Socket             *const q;
-    QSslSocket         *socket;
-    QString             server;
-    QString             protocol;
-    int                 port;
-    bool                secure;
+    Socket *const q;
+    QSslSocket *socket = nullptr;
+    QString server;
+    QString protocol;
+    int port = 0;
+    bool secure = false;
 
     // slots
     void slotConnected();
     void slotStateChanged(QAbstractSocket::SocketState state);
-    void slotModeChanged(QSslSocket::SslMode  state);
+    void slotModeChanged(QSslSocket::SslMode state);
     void slotSocketRead();
     void slotSslErrors(const QList<QSslError> &errors);
 
 private:
     QString m_msg;
 };
-
 }
 
-SocketPrivate::SocketPrivate(Socket *s) :
-    q(s),
-    socket(Q_NULLPTR),
-    port(0),
-    secure(false)
+SocketPrivate::SocketPrivate(Socket *s)
+    : q(s)
 {
 }
 
@@ -73,7 +54,7 @@ void SocketPrivate::slotConnected()
 
     if (!secure) {
         qCDebug(MAILTRANSPORT_LOG) << "normal connect";
-        emit q->connected();
+        Q_EMIT q->connected();
     } else {
         qCDebug(MAILTRANSPORT_LOG) << "encrypted connect";
         socket->startClientEncryption();
@@ -83,20 +64,20 @@ void SocketPrivate::slotConnected()
 void SocketPrivate::slotStateChanged(QAbstractSocket::SocketState state)
 {
 #ifdef comm_debug
-    qCDebug(MAILTRANSPORT_LOG) << "State is now:" << (int) state;
+    qCDebug(MAILTRANSPORT_LOG) << "State is now:" << (int)state;
 #endif
     if (state == QAbstractSocket::UnconnectedState) {
-        emit q->failed();
+        Q_EMIT q->failed();
     }
 }
 
-void SocketPrivate::slotModeChanged(QSslSocket::SslMode  state)
+void SocketPrivate::slotModeChanged(QSslSocket::SslMode state)
 {
 #ifdef comm_debug
     qCDebug(MAILTRANSPORT_LOG) << "Mode is now:" << state;
 #endif
     if (state == QSslSocket::SslClientMode) {
-        emit q->tlsDone();
+        Q_EMIT q->tlsDone();
     }
 }
 
@@ -118,7 +99,7 @@ void SocketPrivate::slotSocketRead()
     qCDebug(MAILTRANSPORT_LOG) << socket->isEncrypted() << m_msg.trimmed();
 #endif
 
-    emit q->data(m_msg);
+    Q_EMIT q->data(m_msg);
     m_msg.clear();
 }
 
@@ -128,13 +109,14 @@ void SocketPrivate::slotSslErrors(const QList<QSslError> &)
     /* We can safely ignore the errors, we are only interested in the
     capabilities. We're not sending auth info. */
     socket->ignoreSslErrors();
-    emit q->connected();
+    Q_EMIT q->connected();
 }
 
 // ------------------ end private ---------------------------//
 
 Socket::Socket(QObject *parent)
-    : QObject(parent), d(new SocketPrivate(this))
+    : QObject(parent)
+    , d(new SocketPrivate(this))
 {
     qCDebug(MAILTRANSPORT_LOG);
 }
@@ -142,12 +124,11 @@ Socket::Socket(QObject *parent)
 Socket::~Socket()
 {
     qCDebug(MAILTRANSPORT_LOG);
-    delete d;
 }
 
 void Socket::reconnect()
 {
-    qCDebug(MAILTRANSPORT_LOG) << "Connecting to:" << d->server <<  ":" <<  d->port;
+    qCDebug(MAILTRANSPORT_LOG) << "Connecting to:" << d->server << ":" << d->port;
 
 #ifdef comm_debug
     // qCDebug(MAILTRANSPORT_LOG) << d->protocol;
@@ -156,22 +137,19 @@ void Socket::reconnect()
     if (d->socket) {
         return;
     }
-    
+
     d->socket = new QSslSocket(this);
     d->socket->setProxy(QNetworkProxy::DefaultProxy);
     d->socket->connectToHost(d->server, d->port);
 
     d->socket->setProtocol(QSsl::AnyProtocol);
 
-    connect(d->socket, SIGNAL(stateChanged(QAbstractSocket::SocketState)),
-            SLOT(slotStateChanged(QAbstractSocket::SocketState)));
-    connect(d->socket, SIGNAL(modeChanged(QSslSocket::SslMode)),
-            SLOT(slotModeChanged(QSslSocket::SslMode)));
+    connect(d->socket, SIGNAL(stateChanged(QAbstractSocket::SocketState)), SLOT(slotStateChanged(QAbstractSocket::SocketState)));
+    connect(d->socket, SIGNAL(modeChanged(QSslSocket::SslMode)), SLOT(slotModeChanged(QSslSocket::SslMode)));
     connect(d->socket, SIGNAL(connected()), SLOT(slotConnected()));
     connect(d->socket, SIGNAL(readyRead()), SLOT(slotSocketRead()));
     connect(d->socket, &QSslSocket::encrypted, this, &Socket::connected);
-    connect(d->socket, SIGNAL(sslErrors(QList<QSslError>)),
-            SLOT(slotSslErrors(QList<QSslError>)));
+    connect(d->socket, SIGNAL(sslErrors(QList<QSslError>)), SLOT(slotSslErrors(QList<QSslError>)));
 }
 
 void Socket::write(const QString &text)
@@ -202,7 +180,7 @@ bool Socket::available()
 void Socket::startTLS()
 {
     qCDebug(MAILTRANSPORT_LOG) << objectName();
-    d->socket->setProtocol(QSsl::TlsV1_0OrLater);
+    d->socket->setProtocol(QSsl::TlsV1_2OrLater);
     d->socket->startClientEncryption();
 }
 
